#!/bin/bash


cat << "EOF"
       _                          _   _             _                
      (_)                        (_) | |           | |               
       _    __ _    __ _   _ __   _  | |_        __| |   ___  __   __
      | |  / _` |  / _` | | '__| | | | __|      / _` |  / _ \ \ \ / /
      | | | (_| | | (_| | | |    | | | |_   _  | (_| | |  __/  \ V / 
      | |  \__,_|  \__, | |_|    |_|  \__| (_)  \__,_|  \___|   \_/  
     _/ |           __/ |                                            
    |__/           |___/                                             
                                                                      
    Kubernetes Setup Script for All Nodes
EOF


# Set Kubernetes version
K8S_VERSION="1.29.0-1.1"

# Update package index and install dependencies
sudo apt-get update -y
sudo apt-get install -y apt-transport-https ca-certificates curl gnupg lsb-release

# Disable swap
sudo swapoff -a
sudo sed -i '/ swap / s/^/#/' /etc/fstab

# Configure kernel parameters
cat <<EOF | sudo tee /etc/modules-load.d/k8s.conf
overlay
br_netfilter
EOF

sudo modprobe overlay
sudo modprobe br_netfilter

cat <<EOF | sudo tee /etc/sysctl.d/k8s.conf
net.bridge.bridge-nf-call-iptables = 1
net.ipv4.ip_forward = 1
net.bridge.bridge-nf-call-ip6tables = 1
EOF

sudo sysctl --system

# Add Kubernetes apt repository
curl -fsSL https://pkgs.k8s.io/core:/stable:/v1.28/deb/Release.key | sudo gpg --dearmor -o /etc/apt/keyrings/kubernetes-1-28-apt-keyring.gpg
echo 'deb [signed-by=/etc/apt/keyrings/kubernetes-1-28-apt-keyring.gpg] https://pkgs.k8s.io/core:/stable:/v1.28/deb/ /' | sudo tee /etc/apt/sources.list.d/kubernetes-1.28.list

curl -fsSL https://pkgs.k8s.io/core:/stable:/v1.29/deb/Release.key | sudo gpg --dearmor -o /etc/apt/keyrings/kubernetes-1-29-apt-keyring.gpg
echo 'deb [signed-by=/etc/apt/keyrings/kubernetes-1-29-apt-keyring.gpg] https://pkgs.k8s.io/core:/stable:/v1.29/deb/ /' | sudo tee /etc/apt/sources.list.d/kubernetes-1.29.list

# Install kubeadm, kubelet, and kubectl
sudo apt-get update -y
sudo apt-get install -y kubelet=$K8S_VERSION kubeadm=$K8S_VERSION kubectl=$K8S_VERSION
sudo apt-get update -y
sudo apt-mark hold kubelet kubeadm kubectl